#
# INOLE-A.MAK
# Common Compiler Flags and Definitions
#
# Copyright (c)1993-1995 Microsoft Corporation, All Rights Reserved
#
# Kraig Brockschmidt, Microsoft
# Internet  :  kraigb@microsoft.com
# Compuserve:  >INTERNET:kraigb@microsoft.com
#

#
# This makefile (and inole2b.mak) builds Win16/Win32, Unicode/ANSI,
# MDI/SDI, and DEBUG/NODEBUG versions.  The default build is Win32,
# Unicode, MDI, DEBUG.
#
# To build different versions set the appropriate environment
# variable below with "SET <variable>=1:
#
#   Variable    Effect
#   -------------------------------
#   ANSI        Build ANSI version (uses OLE2ANSI libs)
#   CLEAN       Cleans up compiled files, overriding all other functions
#   NODEBUG     Build non-debug version
#   SDI         Build SDI version
#   WIN16       Build 16-bit version
#
# In addition, other makefiles control other compilation
# aspects with these variables:
#
#   Variable    Effect
#   -------------------------------------------
#   TARGET      The main filename (no extension) of the project
#   OUTFILE     The final output filename
#   NODOC       Disables SDI/MDI differences
#   NOPRECOMP   Suppresses creation of precompiled header
#   PCHINC      Alternate header to precompile (default is $(TARGET).H
#   DLL         Switches compiler/linker flags for a DLL.
#   NOUILIB     Prevents inclusion of UI library during linking
#   NOCLASSLIB  Prevents inclusion of class libraries during linking
#   TLBHEAD     Name of a type library output header file with /h
#

!ifndef ANSI
DEFUNICODE = -DUNICODE -D_UNICODE
ANSILIB    =
!else
DEFUNICODE = -DOLE2ANSI
ANSILIB    = bookansi.lib
!endif

!ifndef WIN16

CL32    = -G3s
WX      =

!ifdef DLL
LINKDLL = /DLL
DEFDLL  = -D_DLL
ENTRY   = -entry:LibMain32
!else
LINKDLL =
DEFDLL  =
ENTRY   = ""
!endif

!ifdef NOUILIB
UILIB   =
!else
UILIB   = bookui32.lib
!endif

LINKD32 = -debug:full $(LINKDLL) -debugtype:cv
LINKN32 = -debug:none $(LINKDLL)
DEFS32  = -DWIN32 $(DEFDLL) -D_X86_=1 $(DEFUNICODE)
LIBS32A = crtdll.lib kernel32.lib user32.lib gdi32.lib comdlg32.lib advapi32.lib
LIBS32B = $(ANSILIB) ole32.lib oleaut32.lib uuid.lib $(UILIB)
LIBS32  = $(LIBS32A) $(LIBS32B)

!else

WX      = wx /w

!ifdef DLL
CL32    = -G2s -AL -GD
!else
CL32    = -G2s -AL -Gx -GA
!endif

LINKD32 = /al:16/ONERROR:NOEXE/CO
LINKN32 = /al:16/ONERROR:NOEXE
DEFS32  = -DWIN16


!ifdef NOUILIB
UILIB   =
!else
UILIB   = bookui
!endif

!ifdef DLL
CRTLIB  = ldllcew
!else
CRTLIB  = llibcew
!endif
LIBS32A = libw $(CRTLIB) commdlg shell
LIBS32B = compobj storage ole2 $(UILIB) ole2disp typelib
LIBS32  = $(LIBS32A) $(LIBS32B)

!endif

!ifdef NODOC
DOC     =
CLASSLIB= classMDI.lib
!else
!ifdef SDI
DOC     = -DSDI
CLASSLIB= classSDI.lib
!else
DOC     = -DMDI
CLASSLIB= classMDI.lib
!endif
!endif

#
# Set up precompiled header flags.  By default we'll look for
# $(TARGET).H but a specific makefile can override by defining
# the symbol PCHINC
#

!ifdef NOPRECOMP
PCHFILE =
PCHFLAGS=
!else

!ifndef PCHINC
PCHINC  = $(TARGET).h
!endif

PCHFILE = precomp.pch
PCHFLAGS= -Yu$(PCHINC) -Fpprecomp.pch
!endif


#
#Compiler flags
#Use "SET NODEBUG=1" from command prompt to compile non-debug version.
#

!ifndef NODEBUG
CFLAGS  = -c -Od -Z7 -Ze -W3 -nologo $(CL32)
LINK    = $(LINKD32) /NOD
DEFS    = $(DEFS32) -DSTRICT -DDEBUG
!else
CFLAGS  = -c -Oat -Ze -W3 -nologo $(CL32)
LINK    = $(LINKN32) /NOD
DEFS    = $(DEFS32) -DSTRICT
!endif

!ifdef NOCLASSLIB
LIBS    = $(LIBS32)
!else
LIBS    = bttncur.lib gizmobar.lib stastrip.lib $(CLASSLIB)
!endif


.SUFFIXES: .h .obj .exe .dll .cpp .res .rc .tlb .odl

!ifdef CLEAN
goal:   clean
!else
goal:   $(PCHFILE) $(OUTFILE)
!endif

clean:
    if exist *.pch del *.pch
    if exist *.obj del *.obj
    if exist *.res del *.res
    if exist *.exe del *.exe
    if exist *.dll del *.dll
    if exist *.pdb del *.pdb
    if exist *.exp del *.exp
    if exist *.lib del *.lib
    if exist *.ilk del *.ilk
    if exist *.map del *.map
    if exist *.vcp del *.vcp
    if exist *.tlb del *.tlb
    if exist *.log del *.log
    if exist err.  del err.

Enforce32Bits:
    echo This sample can only be compiled for 32-bit platforms


#####

.c.obj:
    echo ++++++++++
    echo Compiling $*.c
    cl $(CFLAGS) $(PCHFLAGS) $(DEFS) $(DOC) $*.c


.cpp.obj:
    echo ++++++++++
    echo Compiling $*.cpp
    cl $(CFLAGS) $(PCHFLAGS) $(DEFS) $(DOC) $*.cpp


.rc.res:
    echo ++++++++++
    echo Compiling Resources
    rc -r $(DEFS) $(DOC) -fo$@ $*.rc

.odl.tlb:
    echo ++++++++++
    echo Compiling $*.odl
    $(WX) mktyplib /nologo /nocpp $(TLBHEAD) /o $*.log /tlb $*.tlb $*.odl
    type $*.log >> err


precomp.pch : $(INCLS)
    echo ++++++++++
    echo Precompiling $(PCHINC)
    cl $(CFLAGS) $(DEFS) $(DOC) -Yc$(PCHINC) -Fpprecomp.pch -Foprecomp precomp.cpp
